@@ -48,8 +48,9 @@ public:
   virtual void flush();
   virtual void rewind();
   virtual void print(std::ostream&) const;
+  virtual Length size();
   virtual Length estimate();
-  virtual Length saveInto(DataHandle&, TransferWatcher& = TransferWatcher::dummy(), bool dblBufferOK = true);
+
   virtual Offset position();
   virtual bool isEmpty() const;
   virtual void restartReadFrom(const Offset& from);
@@ -60,9 +61,11 @@ public:
   virtual bool moveable() const { return true; }
 
   virtual Offset seek(const Offset&);
+  virtual bool canSeek() const;
   virtual void skip(const Length&);
 
   virtual DataHandle* clone() const;
+  virtual void hash(MD5& md5) const;
 
   // From Streamable
 
