@@ -9,6 +9,7 @@
  */
 
 /// @author Baudouin Raoult
+/// @author Tiago Quintino
 /// @date   Nov 96
 
 #ifndef eckit_TaskInfo_h
@@ -24,6 +25,7 @@
 namespace eckit {
 
 class JSON;
+
 //----------------------------------------------------------------------------------------------------------------------
 
 struct Info {
@@ -96,16 +98,9 @@ class TaskInfo : public Padded<Info,4096>,
                  public NonCopyable {
 public:
 
-// -- Contructors
-
 	TaskInfo();
-
-// -- Destructor
-
 	~TaskInfo();
 
-// -- Methods
-
     void  out(char*, char*);
 	bool  busy(bool = false);
 	const char *name()   const { return name_;  }
@@ -163,6 +158,8 @@ public:
 
 	void stoppable(bool s) { stoppable_ = s;touch(); }
 	bool stoppable() const { return stoppable_; }
+	bool stopTriggered() const { return stop_; }
+	void setStopped() { stopped_ = true; stop_ = false; }
 
 	void touch();
 
@@ -185,20 +182,16 @@ public:
 
 	std::string   host() const             { return host_; }
 
-private:
-
-// -- Methods
+private:  // methods
 
 	void print(std::ostream&) const;
 	void json(JSON&) const;
 
-// -- Friends
-
 	friend std::ostream& operator<<(std::ostream& s,const TaskInfo& p)
 		{ p.print(s); return s; }
 
-	friend JSON& operator<<(JSON& s,const TaskInfo& p)
-		{ p.json(s); return s; }
+    friend JSON& operator<<(JSON& s,const TaskInfo& p)
+        { p.json(s); return s; }
 
 };
 
