@@ -31,9 +31,10 @@ CASE("Parsing uri (path)") {
         EXPECT(uri.scheme() == "unix");
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "path");
-        EXPECT(uri.path() == "path");
+        EXPECT(uri.path() == "local://path");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "unix:path");
@@ -44,8 +45,10 @@ CASE("Parsing uri (path)") {
         EXPECT(uri.scheme() == "unix");
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "//:123");
+        EXPECT(uri.path() == "local:///:123");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "unix://:123");
@@ -56,8 +59,10 @@ CASE("Parsing uri (path)") {
         EXPECT(uri.scheme() == "unix");
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "path");
+        EXPECT(uri.path() == "local://path");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "unix:path");
@@ -68,8 +73,10 @@ CASE("Parsing uri (path)") {
         EXPECT(uri.scheme() == "unix");
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "path1:path2");
+        EXPECT(uri.path() == "local://path1:path2");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "unix:path1:path2");
@@ -81,8 +88,10 @@ CASE("Parsing uri (path)") {
         EXPECT(uri.authority().empty());
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "/folder1/folder2/file");
+        EXPECT(uri.path() == "local:///folder1/folder2/file");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "unix:/folder1/folder2/file");
@@ -94,8 +103,10 @@ CASE("Parsing uri (path)") {
         EXPECT(uri.authority().empty());
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "foo:");
+        EXPECT(uri.path() == "local://foo:");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "unix:foo:");
@@ -107,8 +118,10 @@ CASE("Parsing uri (path)") {
         EXPECT(uri.authority().empty());
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "!");
+        EXPECT(uri.path() == "local://!");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "unix:!");
@@ -120,8 +133,10 @@ CASE("Parsing uri (path)") {
         EXPECT(uri.authority().empty());
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "!");
+        EXPECT(uri.path() == "local://!");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "file:!");
@@ -133,8 +148,10 @@ CASE("Parsing uri (path)") {
         EXPECT(uri.authority().empty());
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
-        EXPECT(uri.path() == "http://nodename/path");
+        EXPECT(uri.name() == "http://nodename/path");
+        EXPECT(uri.path() == "local://http://nodename/path");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "unix:http://nodename/path");
@@ -149,8 +166,10 @@ CASE("Parsing uri (scheme)") {
         EXPECT(uri.authority().empty());
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
-        EXPECT(uri.path() == "///path");
+        EXPECT(uri.name() == "///path");
+        EXPECT(uri.path() == "/path");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "file:///path");
@@ -162,7 +181,9 @@ CASE("Parsing uri (scheme)") {
         EXPECT(uri.authority().empty());
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
+        EXPECT(uri.name() == "/this/is/a/path:with:colons");
         EXPECT(uri.path() == "/this/is/a/path:with:colons");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
@@ -170,14 +191,17 @@ CASE("Parsing uri (scheme)") {
         EXPECT(uri.asString() == "/this/is/a/path:with:colons");
     }
 }
+
 CASE("Parsing uri (query & fragment)") {
     {
         URI uri("file://host:123/path?query#fragment");
         EXPECT(uri.scheme() == "file");
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
-        EXPECT(uri.path() == "//host:123/path");
+        EXPECT(uri.name() == "//host:123/path");
+        EXPECT(uri.path() == "/host:123/path");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment() == "fragment");
         EXPECT(uri.asRawString() == "file://host:123/path#fragment");
@@ -188,8 +212,10 @@ CASE("Parsing uri (query & fragment)") {
         EXPECT(uri.scheme() == "file");
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
-        EXPECT(uri.path() == "///path");
+        EXPECT(uri.name() == "///path");
+        EXPECT(uri.path() == "/path");
         EXPECT(uri.query() == "foo=bar&length=123");
         EXPECT(uri.query("foo") == "bar");
         EXPECT(uri.query("length") == "123");
@@ -203,8 +229,10 @@ CASE("Parsing uri (query & fragment)") {
         EXPECT(uri.scheme() == "file");
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
-        EXPECT(uri.path() == "///path");
+        EXPECT(uri.name() == "///path");
+        EXPECT(uri.path() == "/path");
         EXPECT(uri.query() == "foo=bar&length=123");
         EXPECT(uri.query("foo") == "bar");
         EXPECT(uri.query("length") == "123");
@@ -214,6 +242,7 @@ CASE("Parsing uri (query & fragment)") {
         EXPECT(uri.asString() == "///path");
     }
 }
+
 CASE("Parsing uri (authority)") {
     {
         URI uri("http://username:password@host:123/path");
@@ -221,8 +250,10 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.authority() == "username:password@host:123");
         EXPECT(uri.user() == "username:password");
         EXPECT(uri.host() == "host");
+        EXPECT(uri.hostport() == "host:123");
         EXPECT(uri.port() == 123);
-        EXPECT(uri.path() == "/path");
+        EXPECT(uri.name() == "/path");
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://username:password@host:123/path");
@@ -233,8 +264,10 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.scheme() == "unix");
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
+        EXPECT(uri.hostport().empty());
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "http//:123");
+        EXPECT(uri.path() == "local://http//:123");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "unix:http//:123");
@@ -246,8 +279,10 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.authority() == "username:password@host:123");
         EXPECT(uri.user() == "username:password");
         EXPECT(uri.host() == "host");
+        EXPECT(uri.hostport() == "host:123");
         EXPECT(uri.port() == 123);
-        EXPECT(uri.path() == "path");
+        EXPECT(uri.name() == "path");
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://username:password@host:123path");
@@ -259,8 +294,10 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.authority() == "host:");
         EXPECT(uri.user().empty());
         EXPECT(uri.host() == "host");
+        EXPECT(uri.hostport() == "host:");
         EXPECT(uri.port() == 0);
-        EXPECT(uri.path() == "path");
+        EXPECT(uri.name() == "path");
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://host:path");
@@ -272,8 +309,10 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.authority() == "www.ecmwf.int");
         EXPECT(uri.user().empty());
         EXPECT(uri.host() == "www.ecmwf.int");
+        EXPECT(uri.hostport() == "www.ecmwf.int");
         EXPECT(uri.port() == -1);
         EXPECT(uri.name().empty());
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://www.ecmwf.int");
@@ -285,8 +324,10 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.authority() == "www.ecmwf.int:80");
         EXPECT(uri.user().empty());
         EXPECT(uri.host() == "www.ecmwf.int");
+        EXPECT(uri.hostport() == "www.ecmwf.int:80");
         EXPECT(uri.port() == 80);
         EXPECT(uri.name().empty());
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://www.ecmwf.int:80");
@@ -298,8 +339,10 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.authority() == "www.ecmwf.int");
         EXPECT(uri.user().empty());
         EXPECT(uri.host() == "www.ecmwf.int");
+        EXPECT(uri.hostport() == "www.ecmwf.int");
         EXPECT(uri.port() == -1);
         EXPECT(uri.name() == "/");
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://www.ecmwf.int/");
@@ -311,8 +354,10 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.authority() == "host");
         EXPECT(uri.user().empty());
         EXPECT(uri.host() == "host");
+        EXPECT(uri.hostport() == "host");
         EXPECT(uri.port() == -1);
         EXPECT(uri.name().empty());
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://host");
@@ -324,39 +369,44 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.authority() == "nodename");
         EXPECT(uri.user().empty());
         EXPECT(uri.host() == "nodename");
+        EXPECT(uri.hostport() == "nodename");
         EXPECT(uri.port() == -1);
-        EXPECT(uri.path() == "/path");
+        EXPECT(uri.name() == "/path");
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://nodename/path");
         EXPECT(uri.asString() == "http://nodename/path");
     }
-    {
-        URI uri("marsfs://nodename/path");
-        EXPECT(uri.scheme() == "marsfs");
-        EXPECT(uri.authority().empty());
-        EXPECT(uri.user().empty());
-        EXPECT(uri.host().empty());
-        EXPECT(uri.port() == -1);
-        EXPECT(uri.path() == "//nodename/path");
-        EXPECT(uri.query().empty());
-        EXPECT(uri.fragment().empty());
-        EXPECT(uri.asRawString() == "marsfs://nodename/path");
-        EXPECT(uri.asString() == "marsfs://nodename/path");
-    }
     {
         URI uri("https://localhost:123/path");
         EXPECT(uri.scheme() == "https");
         EXPECT(uri.authority() == "localhost:123");
         EXPECT(uri.user().empty());
         EXPECT(uri.host() == "localhost");
+        EXPECT(uri.hostport() == "localhost:123");
         EXPECT(uri.port() == 123);
-        EXPECT(uri.path() == "/path");
+        EXPECT(uri.name() == "/path");
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "https://localhost:123/path");
         EXPECT(uri.asString() == "https://localhost:123/path");
     }
+/*    {
+        URI uri("marsfs://nodename/path");
+        EXPECT(uri.scheme() == "marsfs");
+        EXPECT(uri.authority().empty());
+        EXPECT(uri.user().empty());
+        EXPECT(uri.host().empty());
+        EXPECT(uri.port() == -1);
+        EXPECT(uri.name() == "//nodename/path");
+        EXPECT(uri.path() == "marsfs://nodename/path");
+        EXPECT(uri.query().empty());
+        EXPECT(uri.fragment().empty());
+        EXPECT(uri.asRawString() == "marsfs://nodename/path");
+        EXPECT(uri.asString() == "marsfs://nodename/path");
+    }
     {
         URI uri("marsfs://localhost:123/path");
         EXPECT(uri.scheme() == "marsfs");
@@ -364,13 +414,15 @@ CASE("Parsing uri (authority)") {
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
         EXPECT(uri.port() == -1);
-        EXPECT(uri.path() == "//localhost:123/path");
+        EXPECT(uri.name() == "//localhost:123/path");
+        EXPECT(uri.path() == "marsfs://localhost:123/path");
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "marsfs://localhost:123/path");
         EXPECT(uri.asString() == "marsfs://localhost:123/path");
-    }
+    }*/
 }
+
 CASE("Stream") {
     {
         URI uriOrig("http://username:password@host:123/path");
@@ -389,7 +441,8 @@ CASE("Stream") {
         EXPECT(uri.user() == "username:password");
         EXPECT(uri.host() == "host");
         EXPECT(uri.port() == 123);
-        EXPECT(uri.path() == "/path");
+        EXPECT(uri.name() == "/path");
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://username:password@host:123/path");
@@ -414,7 +467,7 @@ CASE("Stream") {
         EXPECT(uri.user() == "username:password");
         EXPECT(uri.host() == "host");
         EXPECT(uri.port() == 123);
-        EXPECT(uri.path() == "/path");
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query().empty());
         EXPECT(uri.fragment().empty());
         EXPECT(uri.asRawString() == "http://username:password@host:123/path");
@@ -435,7 +488,8 @@ CASE("Stream") {
         EXPECT(uri.user().empty());
         EXPECT(uri.host().empty());
         EXPECT(uri.port() == -1);
-        EXPECT(uri.path() == "/path");
+        EXPECT(uri.name() == "/path");
+        EXPECT_THROWS_AS(uri.path(), NotImplemented);
         EXPECT(uri.query() == "foo=bar&length=123");
         EXPECT(uri.query("foo") == "bar");
         EXPECT(uri.query("length") == "123");
@@ -443,8 +497,13 @@ CASE("Stream") {
         EXPECT(uri.fragment() == "fragment");
         EXPECT(uri.asRawString() == "http:/path?foo=bar&length=123#fragment");
         EXPECT(uri.asString() == "http:/path?foo=bar&length=123#fragment");
+
+        uri.endpoint(eckit::net::Endpoint("host", 123));
+        EXPECT(uri.host() == "host");
+        EXPECT(uri.port() == 123);
     }
 }
+
 //----------------------------------------------------------------------------------------------------------------------
 
 }  // namespace test
