@@ -63,35 +63,34 @@ enum
 #endif
 
 CrossS::CrossS() :
-    Xsect("MXSECTION"),
-    windProjection_(NoWindProjection),
-    windMode_(NoWindMode),
-    useWindIntensity_(false),
-    outputMode_(ScalarOutput),
-    oroColour_("CYAN"),
-    wScaling_(-100),
-    wMode_(Mv3VerticalVelocity),
-    plotVar_(nullptr)
+    Xsect("MXSECTION")
 {
+    init();
     type_ = "MXSECTION";
     view_ = "MXSECTIONVIEW";
 }
 
 CrossS::CrossS(const char* kw) :
-    Xsect(kw),
-    windProjection_(NoWindProjection),
-    windMode_(NoWindMode),
-    useWindIntensity_(false),
-    outputMode_(ScalarOutput),
-    oroColour_("CYAN"),
-    wScaling_(-100),
-    wMode_(Mv3VerticalVelocity),
-    plotVar_(nullptr)
+    Xsect(kw)
 {
+    init();
     type_ = kw;
     view_ = "MXSECTIONVIEW";
 }
 
+void CrossS::init()
+{
+    Xsect::init();
+    windProjection_ = NoWindProjection;
+    windMode_ = NoWindMode;
+    useWindIntensity_ = false;
+    outputMode_ = ScalarOutput;
+    oroColour_ = "CYAN";
+    wScaling_ = -100;
+    wMode_ = Mv3VerticalVelocity;
+    plotVar_ = nullptr;
+}
+
 bool CrossS::getCoordinates(MvRequest& in, ApplicationInfo& appInfo)
 {
     // Get input values
@@ -160,6 +159,9 @@ bool CrossS::getAppParameters(MvRequest& in, ApplicationInfo& appInfo)
     if ((const char*)in("VERTICAL_COORDINATE_PARAM"))
         appInfo.setGHBC((int)in("VERTICAL_COORDINATE_PARAM"));
 
+    if (const char *ch = in("VERTICAL_COORDINATE_EXTRAPOLATE"))
+        appInfo.setGHBCExtrapolate(strcmp(ch, "ON") == 0);
+
     // W wind component computation mode/scaling factor
     std::string wModeStr;
     CROSS_S_CHK(in.getValue("W_WIND_SCALING_FACTOR_MODE", wModeStr));
