@@ -444,7 +444,7 @@ public:
     // -----
 
     //! Returns the number of parameters
-    int countParameters() const;
+    int countParameters(bool includeHidden=true) const;
 
     //! Returns the name of the 'n'th parameter
     /*! NOTE: Method uses C style indexing (n=0,1,...) */
@@ -522,10 +522,10 @@ public:
     /*! if the second parameter is true then any request parameter,
     *  which is an icon (subrequest), will be expanded
     */
-    void read(const char* file, bool expand = false);
+    void read(const char* file, bool expand = false, bool shidden = false);
 
     //! Saves a request into file named 'file'
-    void save(const char* file) const;
+    void save(const char* file, bool hidden = false) const;
 
     //! Saves a request into an open writable C FILE*
     void save(FILE* file) const;
