@@ -20,9 +20,10 @@
 #include "mir/api/MIRJob.h"
 #include "mir/config/LibMir.h"
 #include "mir/input/MIRInput.h"
+#include "mir/key/Key.h"
+#include "mir/key/style/MIRStyle.h"
 #include "mir/param/CombinedParametrisation.h"
 #include "mir/param/DefaultParametrisation.h"
-#include "mir/style/MIRStyle.h"
 #include "mir/util/MIRStatistics.h"
 
 
@@ -31,8 +32,7 @@ namespace action {
 
 
 Job::Job(const api::MIRJob& job, input::MIRInput& input, output::MIROutput& output, bool compress) :
-    input_(input),
-    output_(output) {
+    input_(input), output_(output) {
 
     // get input and parameter-specific parametrisations
     static param::DefaultParametrisation defaults;
@@ -43,7 +43,7 @@ Job::Job(const api::MIRJob& job, input::MIRInput& input, output::MIROutput& outp
     // input is already what was specified
 
     bool postProcessingRequested = false;
-    for (auto& keyword : LibMir::postProcess()) {
+    for (auto& keyword : key::Key::postProcess()) {
         if (job.has(keyword)) {
             postProcessingRequested = true;
             break;
@@ -68,7 +68,7 @@ Job::Job(const api::MIRJob& job, input::MIRInput& input, output::MIROutput& outp
     combined_.reset(new param::CombinedParametrisation(job, metadata, defaults));
     plan_.reset(new action::ActionPlan(*combined_));
 
-    std::unique_ptr<style::MIRStyle> style(style::MIRStyleFactory::build(*combined_));
+    std::unique_ptr<key::style::MIRStyle> style(key::style::MIRStyleFactory::build(*combined_));
     style->prepare(*plan_, input_, output_);
     ASSERT(plan_->ended());
 
